.. webapi-error::
   :instance: reviewboard.webapi.errors.INVALID_USER

   The username specified in a request does not exist
   on the server. This isn't related to
   authentication, but rather for usernames that are
   passed as parameters in some request, such as when
   creating a review request as another user.
